tfseqestimator
==============
Sequence estimators for TensorFlow


Available estimators
--------------------
1. FullSequenceClassifier
2. FullSequenceRegressor
3. SequenceItemsClassifier
4. SequenceItemsRegressor
